
%global goroot /usr/lib/golang
%global gopath /gocode

# This if for the .go files
%global sdk_src_path /src/github.com/oracle/oci-go-sdk

# This is used to create the configuration files
# The default value for the RPM builtin _datadir macro is /usr/share
# This can be changed in the .rpmmacros file
%global preferred_3rdparty_gopath %{_datadir}

# No need to have a debuginfo rpm for this package
%define debug_package %{nil}

# Note that the name of the RPM (go-oci-sdk) is switched
# wrt the name of the package on github (oci-go-sdk)
%define sdkname oci-go-sdk

Name:           go-oci-sdk
Version:        25.1.0
Release:        1%{?dist}
Summary:        Go SDK for Oracle Cloud Infrastructure
Group:          Development/go

License:        UPL
URL:            https://godoc.org/github.com/oracle/oci-go-sdk
Source0:        %{sdkname}-%{version}.zip

Requires: golang

# Two files are generated which contain commands to set
# the GOPATH env variable correctly for the oci-go-sdk users
# There are two flavors, one for bash and one for C shell
%define config_sh_script %{name}-config.sh
%define config_csh_script %{name}-config.csh
%define config_script_dir /etc/profile.d

%description
This is the official Go SDK for Oracle Cloud Infrastructure

%prep
# The zip file from github unpacks as oci-go-sdk, (w/o the version number)
%setup -q -n %{sdkname}

# Generate the sh version of the script to set up the GOPATH env variable
cat > %{config_sh_script} <<EOF
#!/bin/bash
# This file is intended to set GOPATH for go-oci-sdk
# Make sure you run this script with "source" instead of "sh"
# otherwise the setting of the environment variable will not take place
if [ -z "\${GOPATH}" ] ; then
  export GOPATH="%{preferred_3rdparty_gopath}%{gopath}"
else
  export GOPATH="\$GOPATH:%{preferred_3rdparty_gopath}%{gopath}"
fi
EOF

# Generate the tcsh version of the script to set up the GOPATH env variable
cat > %{config_csh_script} <<EOF
#!/bin/tcsh
# This file is intended to set GOPATH for go-oci-sdk
# Make sure you run this script with "source" instead of "tcsh"
# otherwise the setting of the environment variable will not take place
if ( ! \$?GOPATH ) then
  setenv GOPATH ""
endif

if ( "\$GOPATH" == "" ) then
  setenv GOPATH %{preferred_3rdparty_gopath}%{gopath}
else
  setenv GOPATH \$GOPATH\:%{preferred_3rdparty_gopath}%{gopath}
endif
EOF

%build

# Nothing to do here, we just need to install the files
# packaged in the zip file, they do not need to be built

%install

# Create /etc/profile.d under the buildroot to store the
# shell configuration scripts
mkdir -p $RPM_BUILD_ROOT%{config_script_dir}

# Install the two configuration scripts
install -m 644 %{config_sh_script} $RPM_BUILD_ROOT%{config_script_dir}
install -m 644 %{config_csh_script} $RPM_BUILD_ROOT%{config_script_dir}

# Remove them from the BUILD directory
rm -f %{config_sh_script}
rm -f %{config_csh_script}


# Create /usr/share/gocode/src/github.com/oracle/oci-go-sdk under
# the buildroot to store the sdk files
install -d %{buildroot}%{preferred_3rdparty_gopath}%{gopath}%{sdk_src_path}


cp -r %{_builddir}/%{sdkname}/* %{buildroot}%{preferred_3rdparty_gopath}%{gopath}%{sdk_src_path}/
chmod 755 %{buildroot}%{preferred_3rdparty_gopath}%{gopath}%{sdk_src_path}/

%files
%doc
%{preferred_3rdparty_gopath}%{gopath}%{sdk_src_path}/*
%{config_script_dir}/%{config_sh_script}
%{config_script_dir}/%{config_csh_script}


%changelog
* Wed Sep 23 2020 Elena Zannoni <elena.zannoni@oracle.com> - 25.1.0-1
- Import version 25.1.0

* Thu Jul 23 2020 Elena Zannoni <elena.zannoni@oracle.com> - 21.3.0-1
- Import version 21.3.0
- Remove workaround for executable file in example directory
- Add Group

* Wed Jun 17 2020 Elena Zannoni <elena.zannoni@oracle.com> - 20.0.0-3
- Fix the two scripts to actually do the right thing
- Bump version to -3

* Wed Jun 17 2020 Elena Zannoni <elena.zannoni@oracle.com> - 20.0.0-2
- Add Requires golang

* Mon Jun 15 2020 Elena Zannoni <elena.zannoni@oracle.com> - 20.0.0-1
- Import new 20.0.0 release
- Orabug: 31492865
- Work around wrong permissions for one file in the upstreaam distro
- Major cleanup and semplilfication of the spec file

* Fri May 24 2019 Stephen Kyoungwon Kim <stephen.kim@oracle.com> - 5.10.0-2
- Move the package to /usr/share/gocode, which seems a preferred location for 3rd party packages

* Fri May 24 2019 Stephen Kyoungwon Kim <stephen.kim@oracle.com> - 5.10.0-1
- Import 5.10.0

* Fri May 24 2019 Stephen Kyoungwon Kim <stephen.kim@oracle.com> - 5.4.0-3
- Include /usr/lib/golang/src/github.com/oracle/oci-go-sdk directory in the package
- Oracle-Bug: 29909474

* Fri May 24 2019 Stephen Kyoungwon Kim <stephen.kim@oracle.com> - 5.4.0-2
- updated to keep Lans' changes made in 4.0.0-3

* Fri May 24 2019 Tianyue Lan <tianyue.lan@oracle.com> - 5.4.0-1
- import v5.4.0 as of May 21 2019
- Stephen <stephen.kim@oracle.com> cherry-picked from Tianyue's original commit

* Tue May 21 2019 Lans Hung <lans.hung@oracle.com> 4.0.0-3
- Fix spec file to build for specific version only.
- Change install location to /usr/lib instead of /usr/lib64
- Fix error when downloading dependency from upstream during build step. 
  Use go get golang.org/x/lint/golint instead of go get -u github.com/golang/lint/golint

* Tue Mar 05 2019 Lans Hung <lans.hung@oracle.com> - 4.0.0-1
- Initialize package.

